==> action-stat-0.0.2.tgz: package/public/js/index.js <==
/**
 * Created by Administrator on 2016/1/13.
 */
$(function () {
    function getFormData(ele){
        var arr = $(ele).serializeArray();
        var result = {};
        $.each(arr, function(i, d){
            if(result.hasOwnProperty(d.name) && d.value){
                result[d.name] += ',' + d.value;
            }else{
                result[d.name] = d.value;
            }
        });
        return result;
    }
    function template(str, data){
        return str.replace(/\{(\w+)\}/g, function(s1, s2){
            if(data.hasOwnProperty(s2)){
                return data[s2];
            }else{
                return s1;
            }
        });
    }

    $('#add').click(function(){
        var d = getFormData('#fm');
        $.get('/users/add', d, function(result){
            console.log(JSON.stringify(result));
            _find();
        });
    });


    var tpl = $('#tpl').html();
    var dList = $('#dList');
    $('#find').click(_find);
    $('#findstate').click(function(){
        $.get('/state/find', function (result) {
            var str =  '';
            var tpl = $("#tpl2").html();
            var dList = $('#stateList');
            if(result.code === 1){
                $.each(result.d, function(i, o){
                    str += template(tpl, {str: JSON.stringify(o)});
                });
            }else{
                str = '<h2>没有数据</h2>';
            }
            dList.html(str);
        });
    });

    function _find(){
        $.get('/users/find', _dealResult);
    }

    function _dealResult(result){
        var str =  '';
        if(result.code === 1){
            $.each(result.d, function(i, o){
                str += template(tpl, o);
            });
        }else{
            str = '<h2>没有数据</h2>';
        }
        dList.html(str);
    }
});

==> action-stat-0.0.16.tgz: package/public/js/index.js <==
/**
 * Created by Administrator on 2016/1/13.
 */
$(function () {
    $('#add').click(function(){
        var d = BBM.getFormData('#fm');
        $.get('/users/add', d, function(result){
            console.log(JSON.stringify(result));
            _find();
        });
    });


    var tpl = $('#tpl').html();
    var dList = $('#dList');
    $('#find').click(_find);
    $('#findstate').click(function(){
        $.get('/state/find', function (result) {
            var str =  '';
            var tpl = $("#tpl2").html();
            var dList = $('#stateList');
            if(result.code === 1){
                $.each(result.d, function(i, o){
                    str += BBM.template(tpl, {str: JSON.stringify(o)});
                });
            }else{
                str = '<h2>没有数据</h2>';
            }
            dList.html(str);
        });
    });

    $('#find3').click(function(){
        $.get('/state/findcuid', function (result) {
            var str =  '';
            var tpl = $("#tpl2").html();
            var dList = $('#list3');
            if(result.code === 1){
                $.each(result.d, function(i, o){
                    str += BBM.template(tpl, {str: JSON.stringify(o)});
                });
            }else{
                str = '<h2>没有数据</h2>';
            }
            dList.html(str);
        });
    });

    function _find(){
        $.get('/users/find', _dealResult);
    }

    function _dealResult(result){
        var str =  '';
        if(result.code === 1){
            $.each(result.d, function(i, o){
                str += BBM.template(tpl, o);
            });
        }else{
            str = '<h2>没有数据</h2>';
        }
        dList.html(str);
    }
});
